# Welcome To The Calculator!
============================
> - Use For Calculation Of Two Numbers.

# Usage :
---------
> -  Add Two Numbers.
> -  SubTwo Numbers. 
> -  MulTwo Numbers.
> -  DivTwo Numbers.
> -  AvgTwo Numbers. 

```
For Ex :
--------
### Input :
> - obj = calculator
> - obj.add(3,3)
> - obj.sub(3,3)
> - obj.mul(3,3)
> - obj.div(3,3)
> - obj.avg(3,3)

### Output :
> - 6
> - 0 
> - 9
> - 1
> - 3
```

